# pyhandlers
[![Downloads](https://pepy.tech/badge/pyhandlers)](https://pepy.tech/project/pyhandlers)
-----

**Table of Contents**

* [Installation](#installation)
* [License](#license)

## Installation

pyhandlers is distributed on [PyPI](https://pypi.org) as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 3.6+.

```bash
$ pip install pyhandlers
```

## License

pyhandlers is distributed under the terms of the
[MIT License](https://choosealicense.com/licenses/mit).
